@@ -30,36 +30,45 @@
 #' get_playlists(filter=c(channel_id="UCMtFAi84ehTSYSE9X")) # incorrect Channel ID
 #' }
 
-get_playlists <- function (filter = NULL, part = c("contentDetails", "id", "localizations", "player", "snippet", "status"), max_results = 50, hl = NULL, page_token = NULL, simplify = TRUE, ...) {
+get_playlists <- function (filter = NULL,
+                          part = c("contentDetails", "id", "localizations",
+                                   "player", "snippet", "status"),
+                          max_results = 50, hl = NULL,
+                          page_token = NULL, simplify = TRUE, ...) {
 
-	if (max_results < 0 | max_results > 50) stop("max_results only takes a value between 0 and 50.")
+  if (max_results < 0 | max_results > 50) {
+    stop("max_results only takes a value between 0 and 50.")
+  }
 
-	if (!(names(filter) %in% c("channel_id", "playlist_id"))) stop("filter can only take one of values: channel_id, playlist_id.")
-	if ( length(filter) != 1) stop("filter must be a vector of length 1.\n")
+  if (!(names(filter) %in% c("channel_id", "playlist_id"))) {
+    stop("filter can only take one of values: channel_id, playlist_id.")
+  }
 
-	translate_filter   <- c(channel_id = 'channelId', playlist_id ='id')
-	yt_filter_name     <- as.vector(translate_filter[match(names(filter), names(translate_filter))])
-	names(filter)      <- yt_filter_name
+  if ( length(filter) != 1) stop("filter must be a vector of length 1.\n")
 
-	part      <- match.arg(part)
+  translate_filter   <- c(channel_id = "channelId", playlist_id = "id")
+  yt_filter_name     <- as.vector(translate_filter[match(names(filter),
+                                                      names(translate_filter))])
+  names(filter)      <- yt_filter_name
 
-	querylist <- list(part=part, maxResults = max_results, pageToken = page_token, hl = hl)
-	querylist <- c(querylist, filter)
+  part      <- match.arg(part)
 
-	raw_res <- tuber_GET("playlists", querylist, ...)
- 	
- 	if (length(raw_res$items) ==0) { 
-    	cat("No playlists available.\n")
-    	if (simplify == TRUE) return(data.frame())
-    	return(list())
+  querylist <- list(part = part, maxResults = max_results,
+                   pageToken = page_token, hl = hl)
+  querylist <- c(querylist, filter)
+
+  raw_res <- tuber_GET("playlists", querylist, ...)
+
+   if (length(raw_res$items) == 0) {
+      cat("No playlists available.\n")
+      if (simplify == TRUE) return(data.frame())
+      return(list())
     }
 
-    if (simplify==TRUE & part=="contentDetails") {
-		simple_res  <- lapply(raw_res$items, function(x) unlist(x))
-		simpler_res <- ldply(simple_res, rbind)
-		return(simpler_res)
-	} 
-
- 	raw_res
-
+    if (simplify == TRUE & part == "contentDetails") {
+    simple_res  <- lapply(raw_res$items, function(x) unlist(x))
+    simpler_res <- ldply(simple_res, rbind)
+    return(simpler_res)
+  }
+  raw_res
 }
